import { RouterView } from 'vue-router';

export default {
    path: '/customer',
    name: 'Customer',
    meta: {
        title: 'customers',
        icon: 'vn:client',
    },
    component: RouterView,
    redirect: { name: 'CustomerMain' },
    menus: {
        main: ['CustomerList', 'CustomerPayments', 'CustomerCreate'],
        card: ['CustomerBasicData'],
    },
    children: [
        {
            path: '',
            name: 'CustomerMain',
            component: () => import('src/pages/Customer/CustomerMain.vue'),
            redirect: { name: 'CustomerList' },
            children: [
                {
                    path: 'list',
                    name: 'CustomerList',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Customer/CustomerList.vue')
                },
                {
                    path: 'payments',
                    name: 'CustomerPayments',
                    meta: {
                        title: 'webPayments',
                        icon: 'vn:onlinepayment',
                    },
                    component: () => import('src/pages/Customer/CustomerPayments.vue')
                },
                {
                    path: 'create',
                    name: 'CustomerCreate',
                    meta: {
                        title: 'createCustomer',
                        icon: 'vn:addperson',
                        roles: ['developer'],
                    },
                    component: () => import('src/pages/Customer/CustomerCreate.vue'),
                },
            ],
        },
        {
            name: 'CustomerCard',
            path: ':id',
            component: () => import('src/pages/Customer/Card/CustomerCard.vue'),
            redirect: { name: 'CustomerSummary' },
            children: [
                {
                    name: 'CustomerSummary',
                    path: 'summary',
                    meta: {
                        title: 'summary',
                        icon: 'launch',
                    },
                    component: () => import('src/pages/Customer/Card/CustomerSummary.vue'),
                },
                {
                    path: 'basic-data',
                    name: 'CustomerBasicData',
                    meta: {
                        title: 'basicData',
                        icon: 'vn:settings',
                    },
                    component: () => import('src/pages/Customer/Card/CustomerBasicData.vue'),
                },
            ],
        },
    ],
};
